![Scoary2 logo (light mode)](media/scoary-2-logo-full.svg#gh-light-mode-only)
![Scoary2 logo (dark mode)](media/scoary-2-logo-full-dark.svg#gh-dark-mode-only)

Scoary2 associates orthogenes (e.g. generated using [OrthoFinder][orthofinder]
or [Roary][roary] to traits. It reports a list of genes sorted by strength of
association per trait. The results can be explored interactively with a simple, static HTML/JS app.


[![bioRxiv](https://img.shields.io/badge/bioRxiv-2023.04.19.537353-b31b1b.svg)](https://www.biorxiv.org/content/10.1101/2023.04.19.537353v1.full)
[![Docker Image Version (latest semver)](https://img.shields.io/docker/v/troder/scoary-2?logo=docker&label=Docker&color=%231D63ED)](https://hub.docker.com/troder/scoary-2)
[![DOI](https://zenodo.org/badge/445173674.svg)](https://zenodo.org/doi/10.5281/zenodo.10352170)


# Wiki

- [Home](https://github.com/MrTomRod/scoary-2/wiki/Home)
- [Installation](https://github.com/MrTomRod/scoary-2/wiki/Installation)
- [Usage](https://github.com/MrTomRod/scoary-2/wiki/Usage)
- [Input](https://github.com/MrTomRod/scoary-2/wiki/Input)
- [Output](https://github.com/MrTomRod/scoary-2/wiki/Output)
- [Tutorial](https://github.com/MrTomRod/scoary-2/wiki/Tutorial)
- [App](https://github.com/MrTomRod/scoary-2/wiki/App)
- [Understanding the p values](https://github.com/MrTomRod/scoary-2/wiki/Understanding-the-p-values)
- [Usage as Python library](https://github.com/MrTomRod/scoary-2/wiki/Usage-as-Python-library)


[orthofinder]: https://github.com/davidemms/OrthoFinder/
[roary]: https://sanger-pathogens.github.io/Roary/

# Paper

The Scoary2 preprint is now available on bioRxiv. Click [here](https://www.biorxiv.org/content/10.1101/2023.04.19.537353v1)) to see it!

> Roder, T. _et al._ Scoary2: Rapid association of phenotypic multi-omics data with microbial pan-genomes.
> _BioRxiv_ (2023) doi:10.1101/2023.04.19.537353.
